==> mx-boot-options_19.5.1.tar.xz: mx-boot-options-19.5.1/translations/mx-boot-options_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live Umgebung festgestellt. Bitte die Root-Partition des
 zu modifizierenden Systems auswählen (nur Linux Partitionen werden angezeigt)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Kernel parameters</source>
        <translation>Kernel-Parameter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Auf &apos;0&apos; setzen um sofort ohne Anzeige des Menüs zu booten oder auf &apos;-1&apos; setzen um unbefristet zu warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Menu timeout</source>
        <translation>Anzeigedauer des Menüs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Boot to</source>
        <translation>Starten von</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Vereinfachte Menüstruktur ohne Untermenüs benutzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Einfache Menüs (ohne Untermenüs) benutzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Mit dieser Option wird der im Grub-Bootmenü ausgewählte Menü-Eintrag  als Voreinstellung für den nächsten Neustart gespeichert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>Enable saving last boot choice</source>
        <translation>Abspeichern der letzten Auswahl beim Booten aktiv schalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Enable theme</source>
        <translation>Thema aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Messages</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Very detailed</source>
        <translation>Sehr ausführlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Detailed (default setting)</source>
        <translation>Ausführlich (Voreinstellung)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Limited</source>
        <translation>Eingeschränkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Display log</source>
        <translation>Log anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>About this application</source>
        <translation>Über dieses Programm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Still running</source>
        <translation>Läuft noch</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Bootsplash wird installiert, bitte warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Updating sources</source>
        <translation>Quellen aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>Installing</source>
        <translation>Installiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Could not install the bootsplash.</source>
        <translation>Bootsplash konnte nicht installiert werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot continue</source>
        <translation>Fortfahren nicht möglich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Es wurde nichts ausgewählt, Bootoptionen können nicht geändert werden. Abbruch...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Chroot-Umgebung konnte nicht erzeugt und Bootoptionen nicht geändert werden. Abbruch...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Updating configuration, please wait</source>
        <translation>Konfiguration wird aktualisiert, bitte warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Updating initramfs...</source>
        <translation>initramfs wird aktualisiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="898"/>
        <source>Updating grub...</source>
        <translation>Grub wird aktualisiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Changes have been successfully applied.</source>
        <translation>Änderungen erfolgreich durchgeführt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="651"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ein Programm zur Auswahl üblicher Start-Up Optionen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>MX Boot Options</source>
        <translation>MX Boot Optionen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Running in a Virtual Machine</source>
        <translation>Ausführung in einer Oracle VM VirtualBox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Das aktuelle System läuft in einer Oracle VM VirtualBox, wodurch Plymouth-Bootsplash nur eingeschränkt funktioniert. Es ist auch keine Splash-Vorschau möglich.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages not installed</source>
        <translation>Pakete für Plymouth sind nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth packages sind derzeit nicht installiert.
OK für das Weitermachen und der Installierung dieser Pakete ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Bilddateien (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Press any key to close</source>
        <translation>Schließen mit beliebiger Taste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Log not found</source>
        <translation>Kein Log gefunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Could not find log at </source>
        <translation>Log konnte nicht gefunden werden unter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Needs reboot</source>
        <translation>Neustart erforderlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Da Plymouth gerade installiert wurde, ist möglicherweise ein Neustart erforderlich, bevor die Vorschau angezeigt werden kann.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>Click to select theme</source>
        <translation>Klicken, um ein Thema auszuwählen</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as root.</source>
        <translation>Dieses Programm muss als root ausgeführt werden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="739"/>
        <source>Select image to display in bootloader</source>
        <translation>Auswahl des Bildes, das im Bootlader angezeigt wird.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="929"/>
        <source>Select GRUB theme</source>
        <translation>GRUB-Thema auswählen</translation>
    </message>
</context>
</TS>

==> mx-boot-options_21.1.01.tar.xz: mx-boot-options-21.1.01/translations/mx-boot-options_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live Umgebung festgestellt. Bitte die Root-Partition des
 zu modifizierenden Systems auswählen (nur Linux Partitionen werden angezeigt)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="38"/>
        <source>Kernel parameters</source>
        <translation>Kernel-Parameter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Auf &apos;0&apos; setzen um sofort ohne Anzeige des Menüs zu booten oder auf &apos;-1&apos; setzen um unbefristet zu warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Menu timeout</source>
        <translation>Anzeigedauer des Menüs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Boot to</source>
        <translation>Starten von</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Vereinfachte Menüstruktur ohne Untermenüs benutzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Einfache Menüs (ohne Untermenüs) benutzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Mit dieser Option wird der im Grub-Bootmenü ausgewählte Menü-Eintrag  als Voreinstellung für den nächsten Neustart gespeichert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>Enable saving last boot choice</source>
        <translation>Abspeichern der letzten Auswahl beim Booten aktiv schalten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Enable theme</source>
        <translation>Thema aktivieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Messages</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Very detailed</source>
        <translation>Sehr ausführlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>Detailed (default setting)</source>
        <translation>Ausführlich (Voreinstellung)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Limited</source>
        <translation>Eingeschränkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Display log</source>
        <translation>Log anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About this application</source>
        <translation>Über dieses Programm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Still running</source>
        <translation>Läuft noch</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Bootsplash wird installiert, bitte warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Updating sources</source>
        <translation>Quellen aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Installing</source>
        <translation>Installiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Could not install the bootsplash.</source>
        <translation>Bootsplash konnte nicht installiert werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot continue</source>
        <translation>Fortfahren nicht möglich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Es wurde nichts ausgewählt, Bootoptionen können nicht geändert werden. Abbruch...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Chroot-Umgebung konnte nicht erzeugt und Bootoptionen nicht geändert werden. Abbruch...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>Updating configuration, please wait</source>
        <translation>Konfiguration wird aktualisiert, bitte warten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>Updating initramfs...</source>
        <translation>initramfs wird aktualisiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>Updating grub...</source>
        <translation>Grub wird aktualisiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Changes have been successfully applied.</source>
        <translation>Änderungen erfolgreich durchgeführt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ein Programm zur Auswahl üblicher Start-Up Optionen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>MX Boot Options</source>
        <translation>MX Boot Optionen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="723"/>
        <source>Running in a Virtual Machine</source>
        <translation>Ausführung in einer Oracle VM VirtualBox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Das aktuelle System läuft in einer Oracle VM VirtualBox, wodurch Plymouth-Bootsplash nur eingeschränkt funktioniert. Es ist auch keine Splash-Vorschau möglich.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages not installed</source>
        <translation>Pakete für Plymouth sind nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth packages sind derzeit nicht installiert.
OK für das Weitermachen und der Installierung dieser Pakete ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="750"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Bilddateien (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Press any key to close</source>
        <translation>Schließen mit beliebiger Taste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Log not found</source>
        <translation>Kein Log gefunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Could not find log at </source>
        <translation>Log konnte nicht gefunden werden unter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Needs reboot</source>
        <translation>Neustart erforderlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Da Plymouth gerade installiert wurde, ist möglicherweise ein Neustart erforderlich, bevor die Vorschau angezeigt werden kann.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>Click to select theme</source>
        <translation>Klicken, um ein Thema auszuwählen</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Dieses Programm muss als root ausgeführt werden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Program for selecting common start-up choices</source>
        <translation type="unfinished">Ein Programm zur Auswahl üblicher Start-Up Optionen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Select image to display in bootloader</source>
        <translation>Auswahl des Bildes, das im Bootlader angezeigt wird.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="941"/>
        <source>Select GRUB theme</source>
        <translation>GRUB-Thema auswählen</translation>
    </message>
</context>
</TS>
